@@ -19,8 +19,8 @@ class CreatorCode:
     """
 
     def __init__(self, data):
+        self.code = data.get('code')
         self.user = User({'id': data.get('id'), 'displayName': data.get('displayName')})
         self.disabled = data.get('status', '').lower() == 'disabled'
-        self.slug = data.get('slug')
         self.verified = data.get('verified', False)
         self.raw_data = data
